<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * MENU GENERATOR                                                                              * -->
	<!-- *********************************************************************************************** -->


	<!-- Generate the menu's box
	   -
	   - This template generates a side box to be used by the menu and calls the menu generator
	   - itself.
	  -->
	<xsl:template name="generate-menu-box">
		<xsl:call-template name="side-box-template">
			<xsl:with-param name="id">menu-box</xsl:with-param>
			<xsl:with-param name="title">
				<xsl:call-template name="get-i18n-string">
					<xsl:with-param name="id">pages</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="contents">
				<xsl:call-template name="generate-menu" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<!-- Generate the menu
	   -
	   - This template generates the contents of the menu box.
	  -->
	<xsl:template name="generate-menu">
		<xsl:call-template name="menu-template">
			<xsl:with-param name="top-level" select="true()" />
			<xsl:with-param name="contents">
				<xsl:for-each select="$d/ws:sitemap/ws:page[ not(@parent or @hidden) ]">
					<xsl:call-template name="top-level-menu-item" />
				</xsl:for-each>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<!-- Generate a top-level menu entry
	   -
	   - This template generates the menu entry for a top-level item from the site map.
	   - It will then search for sub-pages and, if it is set to auto-generate a map of
	   - the page, it will do so.
	   -
	   - Parameters:
	   -   entry            The sitemap node of the page
	  -->
	<xsl:template name="top-level-menu-item">

		<xsl:variable name="id" select="@id" />
		<xsl:variable name="is-current" select="$id = $page" />
		<xsl:variable name="has-children" select="@auto-menu or $d/ws:sitemap/ws:page[ @parent = $id and not( @hidden ) ]" />
		<xsl:variable name="has-active-child" select="$d/ws:sitemap/ws:page[ @parent = $id and not( @hidden ) and @id = $page ]" />

		<!-- Look for the page's title -->
		<xsl:variable name="entry-title">
			<xsl:call-template name="get-page-title">
				<xsl:with-param name="id" select="$id" />
			</xsl:call-template>
		</xsl:variable>

		<!-- Generate the item -->
		<xsl:call-template name="menu-item-template">
			<xsl:with-param name="top-level" select="true()" />
			<xsl:with-param name="is-current" select="$is-current" />
			<xsl:with-param name="title" select="$entry-title" />
			<xsl:with-param name="has-children" select="$has-children" />
			<xsl:with-param name="has-active-child" select="$has-active-child" />
			<xsl:with-param name="link-to" select="concat( $scriptPath , '/' , $lang , '/' , @id )" />
			<xsl:with-param name="sub-menu">
				<!-- Generate sub-menus -->
				<xsl:if test="@auto-menu or $d/ws:sitemap/ws:page[ @parent = $id and not( @hidden ) ]">
					<xsl:call-template name="menu-template">
						<xsl:with-param name="top-level" select="false()" />
						<xsl:with-param name="contents">
							<xsl:if test="@auto-menu">
								<xsl:call-template name="generate-auto-menu" />
							</xsl:if>
							<xsl:for-each select="$d/ws:sitemap/ws:page[ @parent = $id and not( @hidden ) ]">
								<xsl:call-template name="child-menu-item" />
							</xsl:for-each>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:with-param>
		</xsl:call-template>

	</xsl:template>


	<!-- Generate a child menu entry
	   -
	   - This template generates the menu entry for a child item from the site map.
	   -
	   - Parameters:
	   -   entry            The sitemap node of the page
	  -->
	<xsl:template name="child-menu-item">

		<xsl:variable name="id" select="@id" />
		<xsl:variable name="is-current" select="$id = $page" />

		<!-- Look for the page's title -->
		<xsl:variable name="entry-title">
			<xsl:call-template name="get-page-title">
				<xsl:with-param name="id" select="$id" />
			</xsl:call-template>
		</xsl:variable>

		<!-- Generate the item -->
		<xsl:call-template name="menu-item-template">
			<xsl:with-param name="top-level" select="false()" />
			<xsl:with-param name="is-current" select="$is-current" />
			<xsl:with-param name="title" select="$entry-title" />
			<xsl:with-param name="link-to" select="concat( $scriptPath , '/' , $lang , '/' , @id )" />
		</xsl:call-template>

	</xsl:template>


	<!-- Automatic menu generator
	   -
	   - This template generates a sub-menu from HTML elements having a specified
	   - tag within a page.
	  -->
	<xsl:template name="generate-auto-menu">
		<xsl:variable name="auto-menu" select="@auto-menu" />
		<xsl:variable name="pid" select="string( @id )" />
		<xsl:variable name="lid" select="string( $lang )" />

		<xsl:for-each select="wsf:get-page-data( $pid , $lid )//*[ @class = $auto-menu and @id ]">
			<xsl:call-template name="menu-item-template">
				<xsl:with-param name="top-level" select="false()" />
				<xsl:with-param name="is-current" select="false()" />
				<xsl:with-param name="title" select="text()" />
				<xsl:with-param name="link-to" select="concat( $scriptPath , '/' , $lid , '/' , $pid , '#' , @id )" />
			</xsl:call-template>
		</xsl:for-each>

	</xsl:template>


</xsl:stylesheet>

